==> owncloud-9.0.3.tgz: owncloud/apps/files/l10n/vi.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "Lưu trữ không có sẵn",
    "Storage invalid" : "Lưu trữ không hợp lệ",
    "Unknown error" : "Lỗi chưa biết",
    "Unable to set upload directory." : "Không thể thiết lập thư mục tải lên.",
    "Invalid Token" : "Xác thực không hợp lệ",
    "No file was uploaded. Unknown error" : "Không có tập tin nào được tải lên. Lỗi không xác định",
    "There is no error, the file uploaded with success" : "Không có lỗi, các tập tin đã được tải lên thành công",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "The uploaded file exceeds the upload_max_filesize directive in php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Tập tin được tải lên vượt quá MAX_FILE_SIZE được quy định trong mẫu HTML",
    "The uploaded file was only partially uploaded" : "Các tập tin được tải lên chỉ tải lên được một phần",
    "No file was uploaded" : "Chưa có file nào được tải lên",
    "Missing a temporary folder" : "Không tìm thấy thư mục tạm",
    "Failed to write to disk" : "Không thể ghi ",
    "Not enough storage available" : "Không đủ không gian lưu trữ",
    "The target folder has been moved or deleted." : "Thư mục đích đã di chuyển hoặc bị xóa",
    "Upload failed. Could not find uploaded file" : "Tải lên thất bại. Không thể tìm thấy tập tin được tải lên",
    "Upload failed. Could not get file info." : "Tải lên thất bại. Không thể có được thông tin tập tin.",
    "Invalid directory." : "Thư mục không hợp lệ",
    "Files" : "Tập tin",
    "All files" : "Tất cả tệp tin",
    "Favorites" : "Ưa thích",
    "Home" : "Nhà",
    "Close" : "Đóng",
    "Upload cancelled." : "Hủy tải lên",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
    "Total file size {size1} exceeds upload limit {size2}" : "Kích cở tập tin {size1} vượt giới hạn tải lên {size2}",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
    "Could not get result from server." : "Không thể nhận được kết quả từ máy chủ.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Tập tin tải lên đang được xử lý. Nếu bạn rời khỏi trang bây giờ sẽ hủy quá trình này.",
    "Actions" : "Actions",
    "Download" : "Tải về",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
    "Unshare" : "Bỏ chia sẻ",
    "Details" : "Chi tiết",
    "Select" : "Chọn",
    "Pending" : "Đang chờ",
    "Unable to determine date" : "Không thể xác định ngày",
    "This operation is forbidden" : "Thao tác bị cấm",
    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
    "{newName} already exists" : "{newName} đã có",
    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "_%n file_::_%n files_" : ["%n tập tin"],
    "{dirs} and {files}" : "{dirs} và {files}",
    "You don’t have permission to upload or create files here" : "Bạn không có quyền upload hoặc tạo files ở đây",
    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
    "New" : "Tạo mới",
    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
    "File name cannot be empty." : "Tên file không được rỗng",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Dung lượng của {owner} đã hết, không thể tải hay đồng bộ dữ liệu mới!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Dung lượng của {owner} gần hết ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["khớp '{filter}'"],
    "Path" : "Đường dẫn",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Favorite" : "Ưu thích",
    "Folder" : "Thư mục",
    "New folder" : "Tạo thư mục",
    "Upload" : "Tải lên",
    "File handling" : "Xử lý tập tin",
    "Maximum upload size" : "Kích thước tối đa ",
    "max. possible: " : "tối đa cho phép:",
    "Save" : "Lưu",
    "Settings" : "Cài đặt",
    "WebDAV" : "WebDAV",
    "Cancel upload" : "Hủy upload",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Select all" : "Chọn tất cả",
    "Upload too large" : "Tập tin tải lên quá lớn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
    "Text file" : "Tập tin văn bản"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.7.tgz: owncloud/apps/files/l10n/vi.js <==
OC.L10N.register(
    "files",
    {
    "Storage invalid" : "Lưu trữ không hợp lệ",
    "Unknown error" : "Lỗi chưa biết",
    "All files" : "Tất cả tệp tin",
    "Saved" : "Đã lưu",
    "Home" : "Nhà",
    "Close" : "Đóng",
    "Favorites" : "Ưa thích",
    "Could not create folder \"{dir}\"" : "Không thể tạo thư mục “{dir}”",
    "Upload cancelled." : "Hủy tải lên",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "không thể tải {filename} lên do nó là một thư mục hoặc có kích thước bằng 0 byte",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Không đủ dung lượng trống, bạn đang tải {size1} nhưng chỉ còn {size2} trống",
    "Uploading..." : "tải lên...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Tập tin tải lên đang được xử lý. Nếu bạn rời khỏi trang bây giờ sẽ hủy quá trình này.",
    "Actions" : "Actions",
    "Download" : "Tải về",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Disconnect storage" : "Bộ lưu trữ đã ngắt kết nối",
    "Unshare" : "Bỏ chia sẻ",
    "Files" : "Tập tin",
    "Details" : "Chi tiết",
    "Select" : "Chọn",
    "Pending" : "Đang chờ",
    "Unable to determine date" : "Không thể xác định ngày",
    "Invalid path" : "Đường dẫn không hợp lệ",
    "This operation is forbidden" : "Thao tác bị cấm",
    "This directory is unavailable, please check the logs or contact the administrator" : "Thư mục này không sẵn có, hãy kiểm tra log hoặc liên hệ người quản lý",
    "Could not move \"{file}\", target exists" : "Không thể di chuyển \"{file}\", trùng đích đến",
    "Could not move \"{file}\"" : "Không thể di chuyển \"{file}\"",
    "{newName} already exists" : "{newName} đã có",
    "Could not rename \"{fileName}\", it does not exist any more" : "Không thể đổi tên \"{fileName}\", tập tin không tồn tại",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Tên \"{targetName}\" đã được dùng trong thư mục \"{dir}\". Hãy thử tên khác",
    "Could not rename \"{fileName}\"" : "Không thể đổi tên \"{fileName}\"",
    "Could not create file \"{file}\"" : "Không thể tạo tập tin \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Không thể tạo tập tin \"{file}\" vì đã có ",
    "Could not create folder \"{dir}\" because it already exists" : "Không thể tạo thư mục “{dir}” vì đã có",
    "Error deleting file \"{fileName}\"." : "Lỗi khi xóa tập tin \"{fileName}\".",
    "Name" : "Tên",
    "Size" : "Kích cỡ",
    "Modified" : "Thay đổi",
    "_%n folder_::_%n folders_" : ["%n thư mục"],
    "_%n file_::_%n files_" : ["%n tập tin"],
    "{dirs} and {files}" : "{dirs} và {files}",
    "You don’t have permission to upload or create files here" : "Bạn không có quyền upload hoặc tạo files ở đây",
    "_Uploading %n file_::_Uploading %n files_" : ["Đang tải lên %n tập tin"],
    "New" : "Tạo mới",
    "\"{name}\" is an invalid file name." : "\"{name}\" không được chấp nhận",
    "File name cannot be empty." : "Tên file không được rỗng",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Dung lượng của {owner} đã hết, không thể tải hay đồng bộ dữ liệu mới!",
    "Your storage is full, files can not be updated or synced anymore!" : "Your storage is full, files can not be updated or synced anymore!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Dung lượng của {owner} gần hết ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Your storage is almost full ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["khớp '{filter}'"],
    "Path" : "Đường dẫn",
    "_%n byte_::_%n bytes_" : ["%n bytes"],
    "Favorite" : "Ưu thích",
    "Folder" : "Thư mục",
    "New folder" : "Tạo thư mục",
    "Upload" : "Tải lên",
    "File handling" : "Xử lý tập tin",
    "Maximum upload size" : "Kích thước tối đa ",
    "max. possible: " : "tối đa cho phép:",
    "Save" : "Lưu",
    "Settings" : "Cài đặt",
    "Show hidden files" : "Hiện tập các tin ẩn",
    "WebDAV" : "WebDAV",
    "No entries found in this folder" : "Chưa có mục nào trong thư mục",
    "Select all" : "Chọn tất cả",
    "Upload too large" : "Tập tin tải lên quá lớn",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Các tập tin bạn đang tải lên vượt quá kích thước tối đa cho phép trên máy chủ .",
    "Text file" : "Tập tin văn bản"
},
"nplurals=1; plural=0;");
